@@ -2,13 +2,7 @@ package A::B;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.03';
-sub aa {
-  return "aa";
-}
-sub bb {
-return 1;
-}
+our $VERSION = '0.05';
 
 1;
 __END__
